---
title: Einrichten von Flame in Docker Compose
description: 
published: true
date: 2024-02-10T22:51:39.862Z
tags: 
editor: markdown
dateCreated: 2024-02-10T22:51:39.862Z
---

# Einrichten von Flame in Docker Compose

Flame ist eine selbst gehostete Startseite für Ihren Server. Sein Design ist (stark) von SUI inspiriert. Flame ist sehr einfach einzurichten und zu verwenden. Mit integrierten Editoren können Sie im Handumdrehen Ihren eigenen Anwendungs-Hub einrichten – keine Dateibearbeitung erforderlich.

## Voraussetzungen
Stellen Sie sicher, dass Docker und Docker Compose auf Ihrem System installiert sind.

- Docker Installation: [Docker Installationsanleitung](https://docs.docker.com/get-docker/)
- Docker Compose Installation: [Docker Compose Installationsanleitung](https://docs.docker.com/compose/install/)
- Nginx Reverse Proxy Installation

## Schritte

### 1. Docker Compose Datei erstellen
Erstellen Sie eine `docker-compose.yml`-Datei in Ihrem Projektverzeichnis. Hier ist ein einfaches Beispiel:

```yaml
version: '3.6'

services:
  flame:
    image: pawelmalak/flame
    container_name: flame
    volumes:
      - ./data:/app/data
      - /var/run/docker.sock:/var/run/docker.sock # optional but required for Docker integration
    #ports:
    #  - 5005:5005
    environment:
      - PASSWORD=${SECRET}
      - VIRTUAL_HOST=${DOMAIN}
      - VIRTUAL_PORT=5005
      - LETSENCRYPT_HOST=${DOMAIN}
      - LETSENCRYPT_EMAIL=admin@${DOMAIN}

    restart: unless-stopped
    labels:
      - "com.centurylinklabs.watchtower.enable=true"

    networks:
      - default
      - proxy
      - edge-tier

networks:
  proxy:
    name: nginx-proxy
    external: true
  edge-tier:
    name: edge
    external: true
```

### 2. Flame konfigurieren
In der obenstehenden `docker-compose.yml` wird Watchtower konfiguriert, um alle 30 Sekunden nach Aktualisierungen zu suchen. Sie können das Intervall nach Bedarf anpassen.

### 3. Docker Compose ausführen
Führen Sie den folgenden Befehl in Ihrem Projektverzeichnis aus, um Docker Compose zu starten:

```bash
docker-compose up -d
```

### 4. Überwachen Sie die Aktualisierungen
Watchtower wird nun automatisch nach Updates für Ihre Docker-Container suchen und diese aktualisieren. Sie können die Protokolle überwachen, um den Fortschritt zu überprüfen:

```bash
docker logs -f <container_name>
```

Ersetzen Sie `<container_name>` durch den Namen Ihres Watchtower-Containers.

### Hinweis
Stellen Sie sicher, dass Ihre Container mit einem `latest`-Tag oder einer bestimmten Version getaggt sind, damit Watchtower weiß, welche Version heruntergeladen werden soll.

# Quellen

https://github.com/pawelmalak/flame